pub fn hardware_metrics_enabled(filter: &Filter) -> bool
Returns whether the hardware metrics should be registered under filter: any effective level for this module except off registers them.
filter
off